utils::globalVariables(
  c(
    "url_px",
    "published",
    "title",
    "url_bfs",
    "type",
    "href",
    "collection_id"
  )
)